@@ -25,6 +25,7 @@
 #
 #--------------------------------------------------------------------------
 
+from decimal import Decimal
 import sys
 import json
 import isodate
@@ -312,6 +313,28 @@ class TestRuntimeSerialized(unittest.TestCase):
         assert s.query("filter", [',', ',', ','], "[str]", div=",") == "%2C,%2C,%2C"
         assert s.query("filter", [',', ',', ','], "[str]", div="|", skip_quote=True) == ",|,|,"
 
+    def test_serialize_custom_model(self):
+
+        class CustomSample(Model):
+            _validation = {
+                    'a': {'required': True},
+            }
+
+            _attribute_map = {
+                'a': {'key': 'a', 'type': 'str'},
+            }
+
+            def __init__(self, a):
+                self.a = a
+
+        s = Serializer()
+        model = CustomSample("helloworld")
+        serialized = s._serialize(model)
+
+        assert serialized is not None
+        assert isinstance(serialized, dict)
+        assert serialized['a'] == "helloworld"
+
     def test_serialize_direct_model(self):
         testobj = self.TestObj()
         testobj.attr_a = "myid"
@@ -1344,6 +1367,8 @@ class TestRuntimeSerialized(unittest.TestCase):
         except NameError:
             long_type = int
 
+        s = Serializer()
+        assert s.serialize_data(long_type(1), 'object') == long_type(1)
 
         class TestModel(Model):
             _attribute_map = {'data': {'key': 'data', 'type': 'object'}}
@@ -1354,6 +1379,59 @@ class TestRuntimeSerialized(unittest.TestCase):
             'data': {'id': long_type(1)}
         }
 
+    def test_unicode_as_type_object(self):
+        """Test irrelevant on Python 3. But still doing it to test regresssion.
+            https://github.com/Azure/msrest-for-python/issue/221
+        """
+
+        s = Serializer()
+        assert s.serialize_data(u"\ua015", 'object') == u"\ua015"
+
+        class TestModel(Model):
+            _attribute_map = {'data': {'key': 'data', 'type': 'object'}}
+
+        m = TestModel(data = {'id': u"\ua015"})
+        serialized = m.serialize()
+        assert serialized == {
+            'data': {'id': u"\ua015"}
+        }
+
+    def test_datetime_types_as_type_object(self):
+        """https://github.com/Azure/msrest-for-python/issues/223
+        """
+
+        class TestModel(Model):
+            _attribute_map = {'data': {'key': 'data', 'type': 'object'}}
+
+        m = TestModel(data = {
+            'datetime': isodate.parse_datetime('2012-02-24T00:53:52.780Z'),
+            'date': date(2019,5,1),
+            'time': time(11,12,13),
+            'timedelta': timedelta(56)
+        })
+        serialized = m.serialize()
+        assert serialized['data'] == {
+            'datetime': '2012-02-24T00:53:52.780Z',
+            'date': '2019-05-01',
+            'time': '11:12:13',
+            'timedelta': 'P56D'
+        }
+
+    def test_decimal_types_as_type_object(self):
+        """https://github.com/Azure/msrest-for-python/issues/223
+        """
+
+        class TestModel(Model):
+            _attribute_map = {'data': {'key': 'data', 'type': 'object'}}
+
+        m = TestModel(data = {
+            'decimal': Decimal('1.1'),
+        })
+        serialized = m.serialize()
+        assert serialized['data'] == {
+            'decimal': 1.1
+        }
+
     def test_json_with_xml_map(self):
         basic_json = {'age': 37, 'country': 'france'}
 
@@ -2455,6 +2533,19 @@ class TestRuntimeDeserialized(unittest.TestCase):
         m = TestModel.deserialize({'data': {'id': long_type(1)}})
         assert m.data['id'] == long_type(1)
 
+    def test_failsafe_deserialization(self):
+        class Error(Model):
+
+            def __init__(self, **kwargs):
+                self.status = kwargs.pop("status")
+                self.message = kwargs.pop("message")
+
+        with pytest.raises(DeserializationError):
+            self.d(Error, json.dumps(''), 'text/html')
+
+        deserialized = self.d.failsafe_deserialize(Error, json.dumps(''), 'text/html')
+        assert deserialized is None
+
 class TestModelInstanceEquality(unittest.TestCase):
 
     def test_model_instance_equality(self):
